/* $Header: /fridge/cvs/libjcgi/cgi-conf.c,v 1.5 2001/12/11 00:22:37 justins Exp $ */
/*
   
   JCGI - cgi-conf.c          Copyright(c) 2001 Justin David Smith
   justins(at)chaos2.org      http://chaos2.org/
    
   Configuration options common to most CGI
    

   This program is free software; you can redistribute it and/or modify 
   it under the terms of the GNU General Public License as published by 
   the Free Software Foundation, version 2 of the License ONLY.

   This program is distributed in the hope that it will be useful, 
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
#include <assert.h>
#include <libjcgi.h>


void cgi_conf_init(cgi_conf *c) {

   assert(c != NULL);
   
   /* Initialize CGI config params to defaults */
   c->apache_log        = strnewa("/httpd/logs/access.log");
   c->page_title        = strnewa("chaos2");
   c->fg_color          = strnewa("#e0e0e0");
   c->bg_color          = strnewa("#000000");
   c->fg_link           = strnewa("#50e050");
   c->fg_active         = strnewa("#606060");
   c->fg_visited        = strnewa("#40c040");
   c->fg_hover          = strnewa("#60f060");
   c->fg_head           = strnewa("inherit");
   c->bg_head           = strnewa("transparent");
   c->fg_disabled       = strnewa("#707070");
   c->bg_disabled       = strnewa("transparent");
   c->fg_error          = strnewa("#d01010");
   c->bg_error          = strnewa("transparent");
   
}


cgi_conf *cgi_conf_new(void) {

   cgi_conf *c;
   
   /* Attempt to allocate the CGI config structure */
   c = (cgi_conf *)malloc(sizeof(cgi_conf));
   if(c == NULL) return(NULL);
   
   /* Initialize CGI config params to defaults */
   cgi_conf_init(c);
   
   /* Return c */
   return(c);

}


void cgi_conf_free_entries(cgi_conf *c) {

   if(c == NULL) return;
   strreleasea(&c->apache_log);
   strreleasea(&c->page_title);
   strreleasea(&c->fg_color);
   strreleasea(&c->bg_color);
   strreleasea(&c->fg_link);
   strreleasea(&c->fg_active);
   strreleasea(&c->fg_visited);
   strreleasea(&c->fg_hover);
   strreleasea(&c->fg_head);
   strreleasea(&c->bg_head);
   strreleasea(&c->fg_disabled);
   strreleasea(&c->bg_disabled);
   strreleasea(&c->fg_error);
   strreleasea(&c->bg_error);

}


void cgi_conf_free(cgi_conf *c) {

   if(c == NULL) return;
   cgi_conf_free_entries(c);
   free(c);

}


void cgi_conf_release(cgi_conf **c) {

   if(c == NULL) return;
   cgi_conf_free(*c);
   *c = NULL;

}


bool cgi_conf_option(cgi_conf *c, const stringa *var, const stringa *val) {

   assert(c != NULL);
   assert(var != NULL);
   assert(val != NULL);

   if(strequala(var, "titlepage")          || strequala(var, "page_title")) 
      strcopyaa(c->page_title, val);
   else if(strequala(var, "textcolor")     || strequala(var, "fg_color")) 
      strcopyaa(c->fg_color, val);
   else if(strequala(var, "bgcolor")       || strequala(var, "bg_color")) 
      strcopyaa(c->bg_color, val);
   else if(strequala(var, "disablecolor")  || strequala(var, "fg_disabled")) 
      strcopyaa(c->fg_disabled, val);
   else if(strequala(var, "disableback")   || strequala(var, "bg_disabled")) 
      strcopyaa(c->fg_disabled, val);
   else if(strequala(var, "errorcolor")    || strequala(var, "fg_error"))
      strcopyaa(c->fg_error, val);
   else if(strequala(var, "errorback")     || strequala(var, "bg_error"))
      strcopyaa(c->bg_error, val);
   else if(strequala(var, "linkcolor")     || strequala(var, "fg_link"))
      strcopyaa(c->fg_link, val);
   else if(strequala(var, "activecolor")   || strequala(var, "fg_active"))
      strcopyaa(c->fg_active, val);
   else if(strequala(var, "visitedcolor")  || strequala(var, "fg_visited")) 
      strcopyaa(c->fg_visited, val);
   else if(strequala(var, "hovercolor")    || strequala(var, "fg_hover")) 
      strcopyaa(c->fg_hover, val);
   else if(strequala(var, "headcolor")     || strequala(var, "fg_head")) 
      strcopyaa(c->fg_head, val);
   else if(strequala(var, "headback")      || strequala(var, "bg_head")) 
      strcopyaa(c->bg_head, val);
   else if(strequala(var, "apachelog")     || strequala(var, "apache_log") || strequala(var, "apache_log_fs")) 
      strcopyaa(c->apache_log, val);
   else
      /* We don't understand this option */
      return(false);
   
   /* Option was processed */
   return(true);

}
