/* $Header: /fridge/cvs/libjcgi/libjcgi.h.in,v 1.8 2001/12/10 22:56:34 justins Exp $ */
/*
   
   JCGI - libjcgi.h           Copyright(c) 2001 Justin David Smith
   justins(at)chaos2.org      http://chaos2.org/
    
   Main header file for libjcgi
    

   This program is free software; you can redistribute it and/or modify 
   it under the terms of the GNU General Public License as published by 
   the Free Software Foundation, version 2 of the License ONLY.

   This program is distributed in the hope that it will be useful, 
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
#ifndef __libjcgi_included
#define __libjcgi_included


/* Include files */
#include <stdlib.h>
#include <libjstra.h>
#include <libjtree.h>


/* Version information */
#define  __libjcgi_version       ((((long)0 & 0xff) << 24) | (((long)1 & 0xff) << 16) | (((long)12 & 0xff) << 8)) /* Version 0.1.12 */


/* CGI environment structure */
typedef struct _cgi_env {
   stringa *query_string;
   stringa *remote_addr;
   stringa *remote_host;
   stringa *http_user_agent;
   stringa *http_referer;
   stringa *server_name;
   stringa *request_uri;
   bintree *query_args;
   bool query_edit;
} cgi_env;


/* CGI config structure */
typedef struct _cgi_conf {
   stringa *apache_log;
   stringa *page_title;
   stringa *fg_color;
   stringa *bg_color;
   stringa *fg_link;
   stringa *fg_active;
   stringa *fg_visited;
   stringa *fg_hover;
   stringa *fg_head;
   stringa *bg_head;
   stringa *fg_disabled;
   stringa *bg_disabled;
   stringa *fg_error;
   stringa *bg_error;
} cgi_conf;


/* IP Masks */
typedef struct _ip_number {
   unsigned int ip_number;
   unsigned int ip_mask;
} ip_number;


/* CGI Environment Functions */
bintree *parse_query_args(const char *query_string);
void cgi_env_init(cgi_env *e);
cgi_env *cgi_env_new(void);
void cgi_env_free_entries(cgi_env *e);
void cgi_env_free(cgi_env *e);
void cgi_env_release(cgi_env **e);


/* CGI Config Functions */
void cgi_conf_init(cgi_conf *c);
cgi_conf *cgi_conf_new(void);
void cgi_conf_free_entries(cgi_conf *c);
void cgi_conf_free(cgi_conf *c);
void cgi_conf_release(cgi_conf **c);
bool cgi_conf_option(cgi_conf *c, const stringa *var, const stringa *val);


/* CGI Validation Functions */
bool cgi_check_input_chars_html(stringa *input);
bool cgi_check_input_chars_cgi(stringa *input);
bool cgi_check_file_path(const char *path, bool dir_allowed);


/* CGI HTML functions */
void cgi_html_head_begin(const cgi_conf *c, const char *title, const char *copyright);
void cgi_html_gpl(void);
void cgi_html_validator_links(const cgi_env *e);
void cgi_html_init(const char *package, const char *version, const char *copyright);


/* IP number manipulation */
ip_number *ip_number_new(const char *ip);
bool ip_number_init(ip_number *ipn, const char *ip);
bool ip_number_match(const ip_number *ipmask, const ip_number *iptest);
void ip_number_free(ip_number *ipn);
void ip_number_release(ip_number **ipn);


/* CGI version info */
unsigned int libjcgi_version(void);


#endif /* Header included? */

